==> cargo-binstall-1.16.7-1.src.tar.gz: cargo-binstall-1.16.7/crates/binstalk-manifests/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.17.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.7...binstalk-manifests-v0.17.8) - 2025-09-06

### Other

- updated the following local packages: detect-targets

## [0.17.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.6...binstalk-manifests-v0.17.7) - 2025-08-30

### Other

- updated the following local packages: detect-targets

## [0.17.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.5...binstalk-manifests-v0.17.6) - 2025-08-24

### Other

- updated the following local packages: detect-targets

## [0.17.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.4...binstalk-manifests-v0.17.5) - 2025-08-22

### Added

- confirm on the first time using quickinstall ([#2223](https://github.com/cargo-bins/cargo-binstall/pull/2223))

## [0.17.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.3...binstalk-manifests-v0.17.4) - 2025-08-09

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.17.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.2...binstalk-manifests-v0.17.3) - 2025-08-01

### Other

- updated the following local packages: detect-targets

## [0.17.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.1...binstalk-manifests-v0.17.2) - 2025-07-25

### Other

- *(deps)* bump the deps group with 2 updates ([#2227](https://github.com/cargo-bins/cargo-binstall/pull/2227))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.17.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.23...binstalk-manifests-v0.17.24) - 2026-01-18

### Other

- *(deps)* bump the deps group with 8 updates ([#2424](https://github.com/cargo-bins/cargo-binstall/pull/2424))

## [0.17.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.22...binstalk-manifests-v0.17.23) - 2025-12-27

### Other

- updated the following local packages: detect-targets

## [0.17.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.21...binstalk-manifests-v0.17.22) - 2025-12-22

### Other

- updated the following local packages: detect-targets

## [0.17.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.20...binstalk-manifests-v0.17.21) - 2025-12-20

### Other

- *(deps)* bump toml_edit from 0.23.10+spec-1.0.0 to 0.24.0+spec-1.1.0 in the deps group ([#2404](https://github.com/cargo-bins/cargo-binstall/pull/2404))

## [0.17.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.19...binstalk-manifests-v0.17.20) - 2025-12-12

### Other

- updated the following local packages: detect-targets

## [0.17.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.18...binstalk-manifests-v0.17.19) - 2025-12-05

### Other

- updated the following local packages: detect-targets

## [0.17.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.17...binstalk-manifests-v0.17.18) - 2025-11-23

### Other

- updated the following local packages: detect-targets

## [0.17.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.16...binstalk-manifests-v0.17.17) - 2025-11-21

### Other

- updated the following local packages: detect-targets

## [0.17.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.15...binstalk-manifests-v0.17.16) - 2025-11-15

### Other

- support replace-with field for registry ([#2370](https://github.com/cargo-bins/cargo-binstall/pull/2370))

## [0.17.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.14...binstalk-manifests-v0.17.15) - 2025-11-09

### Other

- updated the following local packages: detect-targets

## [0.17.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.13...binstalk-manifests-v0.17.14) - 2025-11-02

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.17.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.12...binstalk-manifests-v0.17.13) - 2025-11-01

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.17.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.11...binstalk-manifests-v0.17.12) - 2025-10-24

### Other

- updated the following local packages: binstalk-types, detect-targets

## [0.17.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.10...binstalk-manifests-v0.17.11) - 2025-10-10

### Other

- updated the following local packages: detect-targets

## [0.17.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.9...binstalk-manifests-v0.17.10) - 2025-09-26

### Other

- updated the following local packages: detect-targets

## [0.17.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.8...binstalk-manifests-v0.17.9) - 2025-09-14

### Other

- updated the following local packages: detect-targets

## [0.17.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.0...binstalk-manifests-v0.17.1) - 2025-06-22

### Other

- updated the following local packages: detect-targets

## [0.17.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.16.1...binstalk-manifests-v0.17.0) - 2025-06-21

### Fixed

- Rm uninstalled crates from binstall/crates-v1.json ([#2197](https://github.com/cargo-bins/cargo-binstall/pull/2197))

## [0.16.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.16.0...binstalk-manifests-v0.16.1) - 2025-06-10

### Other

- updated the following local packages: detect-targets

## [0.16.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.31...binstalk-manifests-v0.16.0) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

### Other

- Optimize CratesToml ([#2186](https://github.com/cargo-bins/cargo-binstall/pull/2186))

## [0.15.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.30...binstalk-manifests-v0.15.31) - 2025-05-30

### Other

- updated the following local packages: detect-targets

## [0.15.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.29...binstalk-manifests-v0.15.30) - 2025-05-16

### Other

- updated the following local packages: detect-targets

## [0.15.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.28...binstalk-manifests-v0.15.29) - 2025-05-07

### Other

- updated the following local packages: detect-targets

## [0.15.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.27...binstalk-manifests-v0.15.28) - 2025-04-05

### Other

- Fix clippy lints ([#2111](https://github.com/cargo-bins/cargo-binstall/pull/2111))

## [0.15.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.26...binstalk-manifests-v0.15.27) - 2025-03-19

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.15.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.25...binstalk-manifests-v0.15.26) - 2025-03-15

### Other

- updated the following local packages: detect-targets

## [0.15.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.24...binstalk-manifests-v0.15.25) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.15.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.23...binstalk-manifests-v0.15.24) - 2025-02-28

### Other

- updated the following local packages: detect-targets

## [0.15.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.22...binstalk-manifests-v0.15.23) - 2025-02-22

### Other

- Log when FileLock::drop fails to unlock file ([#2064](https://github.com/cargo-bins/cargo-binstall/pull/2064))

## [0.15.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.21...binstalk-manifests-v0.15.22) - 2025-02-15

### Other

- updated the following local packages: detect-targets

## [0.15.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.20...binstalk-manifests-v0.15.21) - 2025-02-11

### Other

- updated the following local packages: binstalk-types, detect-targets

## [0.15.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.19...binstalk-manifests-v0.15.20) - 2025-02-04

### Other

- updated the following local packages: detect-targets

## [0.15.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.18...binstalk-manifests-v0.15.19) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.15.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.17...binstalk-manifests-v0.15.18) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.15.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.16...binstalk-manifests-v0.15.17) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.15.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.15...binstalk-manifests-v0.15.16) - 2025-01-04

### Other

- updated the following local packages: detect-targets

## [0.15.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.14...binstalk-manifests-v0.15.15) - 2024-12-28

### Other

- updated the following local packages: detect-targets

## [0.15.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.13...binstalk-manifests-v0.15.14) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.15.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.12...binstalk-manifests-v0.15.13) - 2024-12-07

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.15.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.11...binstalk-manifests-v0.15.12) - 2024-11-29

### Other

- updated the following local packages: detect-targets

## [0.15.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.10...binstalk-manifests-v0.15.11) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.15.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.9...binstalk-manifests-v0.15.10) - 2024-11-18

### Other

- updated the following local packages: detect-targets

## [0.15.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.8...binstalk-manifests-v0.15.9) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.15.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.7...binstalk-manifests-v0.15.8) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.15.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.6...binstalk-manifests-v0.15.7) - 2024-11-02

### Other

- updated the following local packages: detect-targets

## [0.15.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.5...binstalk-manifests-v0.15.6) - 2024-10-25

### Other

- updated the following local packages: detect-targets

## [0.15.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.4...binstalk-manifests-v0.15.5) - 2024-10-12

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.15.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.3...binstalk-manifests-v0.15.4) - 2024-10-04

### Other

- updated the following local packages: detect-targets

## [0.15.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.2...binstalk-manifests-v0.15.3) - 2024-09-22

### Other

- updated the following local packages: detect-targets

## [0.15.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.1...binstalk-manifests-v0.15.2) - 2024-09-06

### Other
- updated the following local packages: detect-targets

## [0.15.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.0...binstalk-manifests-v0.15.1) - 2024-08-25

### Other
- updated the following local packages: detect-targets

## [0.15.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.14.1...binstalk-manifests-v0.15.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, detect-targets

## [0.14.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.14.0...binstalk-manifests-v0.14.1) - 2024-08-04

### Other
- updated the following local packages: detect-targets, fs-lock

==> cargo-binstall-1.17.3-1.src.tar.gz: cargo-binstall-1.17.3/crates/binstalk-manifests/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.17.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.7...binstalk-manifests-v0.17.8) - 2025-09-06

### Other

- updated the following local packages: detect-targets

## [0.17.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.6...binstalk-manifests-v0.17.7) - 2025-08-30

### Other

- updated the following local packages: detect-targets

## [0.17.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.5...binstalk-manifests-v0.17.6) - 2025-08-24

### Other

- updated the following local packages: detect-targets

## [0.17.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.4...binstalk-manifests-v0.17.5) - 2025-08-22

### Added

- confirm on the first time using quickinstall ([#2223](https://github.com/cargo-bins/cargo-binstall/pull/2223))

## [0.17.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.3...binstalk-manifests-v0.17.4) - 2025-08-09

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.17.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.2...binstalk-manifests-v0.17.3) - 2025-08-01

### Other

- updated the following local packages: detect-targets

## [0.17.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.1...binstalk-manifests-v0.17.2) - 2025-07-25

### Other

- *(deps)* bump the deps group with 2 updates ([#2227](https://github.com/cargo-bins/cargo-binstall/pull/2227))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.17.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.24...binstalk-manifests-v0.17.25) - 2026-01-23

### Other

- updated the following local packages: binstalk-types, detect-targets

## [0.17.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.23...binstalk-manifests-v0.17.24) - 2026-01-18

### Other

- *(deps)* bump the deps group with 8 updates ([#2424](https://github.com/cargo-bins/cargo-binstall/pull/2424))

## [0.17.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.22...binstalk-manifests-v0.17.23) - 2025-12-27

### Other

- updated the following local packages: detect-targets

## [0.17.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.21...binstalk-manifests-v0.17.22) - 2025-12-22

### Other

- updated the following local packages: detect-targets

## [0.17.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.20...binstalk-manifests-v0.17.21) - 2025-12-20

### Other

- *(deps)* bump toml_edit from 0.23.10+spec-1.0.0 to 0.24.0+spec-1.1.0 in the deps group ([#2404](https://github.com/cargo-bins/cargo-binstall/pull/2404))

## [0.17.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.19...binstalk-manifests-v0.17.20) - 2025-12-12

### Other

- updated the following local packages: detect-targets

## [0.17.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.18...binstalk-manifests-v0.17.19) - 2025-12-05

### Other

- updated the following local packages: detect-targets

## [0.17.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.17...binstalk-manifests-v0.17.18) - 2025-11-23

### Other

- updated the following local packages: detect-targets

## [0.17.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.16...binstalk-manifests-v0.17.17) - 2025-11-21

### Other

- updated the following local packages: detect-targets

## [0.17.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.15...binstalk-manifests-v0.17.16) - 2025-11-15

### Other

- support replace-with field for registry ([#2370](https://github.com/cargo-bins/cargo-binstall/pull/2370))

## [0.17.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.14...binstalk-manifests-v0.17.15) - 2025-11-09

### Other

- updated the following local packages: detect-targets

## [0.17.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.13...binstalk-manifests-v0.17.14) - 2025-11-02

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.17.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.12...binstalk-manifests-v0.17.13) - 2025-11-01

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.17.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.11...binstalk-manifests-v0.17.12) - 2025-10-24

### Other

- updated the following local packages: binstalk-types, detect-targets

## [0.17.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.10...binstalk-manifests-v0.17.11) - 2025-10-10

### Other

- updated the following local packages: detect-targets

## [0.17.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.9...binstalk-manifests-v0.17.10) - 2025-09-26

### Other

- updated the following local packages: detect-targets

## [0.17.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.8...binstalk-manifests-v0.17.9) - 2025-09-14

### Other

- updated the following local packages: detect-targets

## [0.17.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.17.0...binstalk-manifests-v0.17.1) - 2025-06-22

### Other

- updated the following local packages: detect-targets

## [0.17.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.16.1...binstalk-manifests-v0.17.0) - 2025-06-21

### Fixed

- Rm uninstalled crates from binstall/crates-v1.json ([#2197](https://github.com/cargo-bins/cargo-binstall/pull/2197))

## [0.16.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.16.0...binstalk-manifests-v0.16.1) - 2025-06-10

### Other

- updated the following local packages: detect-targets

## [0.16.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.31...binstalk-manifests-v0.16.0) - 2025-06-06

### Fixed

- fix updating of installed crates manifest on custom sparse registry ([#2178](https://github.com/cargo-bins/cargo-binstall/pull/2178))

### Other

- Optimize CratesToml ([#2186](https://github.com/cargo-bins/cargo-binstall/pull/2186))

## [0.15.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.30...binstalk-manifests-v0.15.31) - 2025-05-30

### Other

- updated the following local packages: detect-targets

## [0.15.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.29...binstalk-manifests-v0.15.30) - 2025-05-16

### Other

- updated the following local packages: detect-targets

## [0.15.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.28...binstalk-manifests-v0.15.29) - 2025-05-07

### Other

- updated the following local packages: detect-targets

## [0.15.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.27...binstalk-manifests-v0.15.28) - 2025-04-05

### Other

- Fix clippy lints ([#2111](https://github.com/cargo-bins/cargo-binstall/pull/2111))

## [0.15.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.26...binstalk-manifests-v0.15.27) - 2025-03-19

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.15.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.25...binstalk-manifests-v0.15.26) - 2025-03-15

### Other

- updated the following local packages: detect-targets

## [0.15.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.24...binstalk-manifests-v0.15.25) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.15.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.23...binstalk-manifests-v0.15.24) - 2025-02-28

### Other

- updated the following local packages: detect-targets

## [0.15.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.22...binstalk-manifests-v0.15.23) - 2025-02-22

### Other

- Log when FileLock::drop fails to unlock file ([#2064](https://github.com/cargo-bins/cargo-binstall/pull/2064))

## [0.15.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.21...binstalk-manifests-v0.15.22) - 2025-02-15

### Other

- updated the following local packages: detect-targets

## [0.15.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.20...binstalk-manifests-v0.15.21) - 2025-02-11

### Other

- updated the following local packages: binstalk-types, detect-targets

## [0.15.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.19...binstalk-manifests-v0.15.20) - 2025-02-04

### Other

- updated the following local packages: detect-targets

## [0.15.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.18...binstalk-manifests-v0.15.19) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.15.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.17...binstalk-manifests-v0.15.18) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.15.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.16...binstalk-manifests-v0.15.17) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.15.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.15...binstalk-manifests-v0.15.16) - 2025-01-04

### Other

- updated the following local packages: detect-targets

## [0.15.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.14...binstalk-manifests-v0.15.15) - 2024-12-28

### Other

- updated the following local packages: detect-targets

## [0.15.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.13...binstalk-manifests-v0.15.14) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.15.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.12...binstalk-manifests-v0.15.13) - 2024-12-07

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.15.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.11...binstalk-manifests-v0.15.12) - 2024-11-29

### Other

- updated the following local packages: detect-targets

## [0.15.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.10...binstalk-manifests-v0.15.11) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.15.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.9...binstalk-manifests-v0.15.10) - 2024-11-18

### Other

- updated the following local packages: detect-targets

## [0.15.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.8...binstalk-manifests-v0.15.9) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.15.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.7...binstalk-manifests-v0.15.8) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.15.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.6...binstalk-manifests-v0.15.7) - 2024-11-02

### Other

- updated the following local packages: detect-targets

## [0.15.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.5...binstalk-manifests-v0.15.6) - 2024-10-25

### Other

- updated the following local packages: detect-targets

## [0.15.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.4...binstalk-manifests-v0.15.5) - 2024-10-12

### Other

- updated the following local packages: detect-targets, fs-lock

## [0.15.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.3...binstalk-manifests-v0.15.4) - 2024-10-04

### Other

- updated the following local packages: detect-targets

## [0.15.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.2...binstalk-manifests-v0.15.3) - 2024-09-22

### Other

- updated the following local packages: detect-targets

## [0.15.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.1...binstalk-manifests-v0.15.2) - 2024-09-06

### Other
- updated the following local packages: detect-targets

## [0.15.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.15.0...binstalk-manifests-v0.15.1) - 2024-08-25

### Other
- updated the following local packages: detect-targets

## [0.15.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.14.1...binstalk-manifests-v0.15.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types, detect-targets

## [0.14.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-manifests-v0.14.0...binstalk-manifests-v0.14.1) - 2024-08-04

### Other
- updated the following local packages: detect-targets, fs-lock
